import { ADMIN_FORMSERVICE } from '@admin-client/shared';
import { EMPTY_STRING } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, mock, Mock, MockEvent, mockGetValue, triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { FormBuilder, FormControl, FormGroup } from '@angular/forms';
import { expect } from '@jest/globals';
import { TextEditorComponent } from '@ods/component';
import { ButtonComponent, DeleteIconComponent } from '@ods/system';
import { MockComponent } from 'ng-mocks';
import { getDataTestIdOf } from '../../../../../../../../tech-shared/test/data-test';
import { AggregationMappingFormservice } from '../../aggregation-mapping.formservice';
import { AggregationMappingFieldFormComponent } from './aggregation-mapping-field-form.component';

describe('AggregationMappingFieldFormComponent', () => {
  let component: AggregationMappingFieldFormComponent;
  let fixture: ComponentFixture<AggregationMappingFieldFormComponent>;

  const formBuilder: FormBuilder = new FormBuilder();
  const fieldIndex: number = 0;
  const sourcePathEditorTestId: string = getDataTestIdOf('source-mapping-field-0');
  const targetPathEditorTestId: string = getDataTestIdOf('target-mapping-field-0');
  const removeMappingButtonTestId: string = getDataTestIdOf('remove-mapping-0');

  let formService: Mock<AggregationMappingFormservice>;

  beforeEach(async () => {
    const form: FormGroup = formBuilder.group({
      [AggregationMappingFormservice.FIELD_MAPPINGS]: formBuilder.array([
        new FormGroup({
          [AggregationMappingFormservice.FIELD_MAPPING_SOURCE_PATH]: new FormControl(EMPTY_STRING),
          [AggregationMappingFormservice.FIELD_MAPPING_TARGET_PATH]: new FormControl(EMPTY_STRING),
        }),
      ]),
    });

    formService = <any>{
      ...mock(AggregationMappingFormservice),
      form,
      addMapping: jest.fn(),
      removeMapping: jest.fn(),
    };

    mockGetValue(
      formService,
      AggregationMappingFormservice.FIELD_MAPPINGS,
      form.controls[AggregationMappingFormservice.FIELD_MAPPINGS],
    );

    await TestBed.configureTestingModule({
      imports: [
        AggregationMappingFieldFormComponent,
        MockComponent(TextEditorComponent),
        MockComponent(ButtonComponent),
        MockComponent(DeleteIconComponent),
      ],
      providers: [
        {
          provide: ADMIN_FORMSERVICE,
          useValue: formService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(AggregationMappingFieldFormComponent);
    component = fixture.componentInstance;
    component.index = fieldIndex;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('remove mapping button', () => {
      it('should exists', () => {
        existsAsHtmlElement(fixture, removeMappingButtonTestId);
      });

      it('should remove mapping on click', () => {
        triggerEvent({ fixture, elementSelector: removeMappingButtonTestId, name: MockEvent.CLICK, data: fieldIndex });

        expect(formService.removeMapping).toHaveBeenCalledWith(fieldIndex);
      });
    });

    describe('source path text editor', () => {
      it('should exists', () => {
        existsAsHtmlElement(fixture, sourcePathEditorTestId);
      });
    });

    describe('target path text editor', () => {
      it('should should exists', () => {
        existsAsHtmlElement(fixture, targetPathEditorTestId);
      });
    });
  });
});
