import { AggregationMappingListLinkRel, AggregationMappingListResource } from '@admin-client/reporting-shared';
import { createStateResource, getEmbeddedResources, StateResource } from '@alfa-client/tech-shared';
import { expectComponentExistsInTemplate, getElementFromFixtureByType } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { expect } from '@jest/globals';
import { SpinnerComponent } from '@ods/component';
import { ListComponent } from '@ods/system';
import { MockComponent } from 'ng-mocks';
import { createAggregationMappingListResource } from '../../../../../reporting-shared/test/aggregation-mapping';
import { AggregationMappingListItemComponent } from './aggregation-mapping-list-item/aggregation-mapping-list-item.component';
import { AggregationMappingListComponent } from './aggregation-mapping-list.component';

describe('AggregationMappingListComponent', () => {
  let component: AggregationMappingListComponent;
  let fixture: ComponentFixture<AggregationMappingListComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [
        AggregationMappingListComponent,
        MockComponent(SpinnerComponent),
        MockComponent(ListComponent),
        MockComponent(AggregationMappingListItemComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(AggregationMappingListComponent);
    component = fixture.componentInstance;
    component.aggregationMappingListStateResource = createStateResource(createAggregationMappingListResource());
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    const aggregationMappingListStateResource: StateResource<AggregationMappingListResource> = createStateResource(
      createAggregationMappingListResource(),
    );

    beforeEach(() => {
      component.aggregationMappingListStateResource = aggregationMappingListStateResource;
      fixture.detectChanges();
    });

    it('should have list', () => {
      expectComponentExistsInTemplate(fixture, ListComponent);
    });

    it('should have spinner with state resource', () => {
      const comp = getElementFromFixtureByType(fixture, SpinnerComponent);
      expect(comp.stateResource).toEqual(aggregationMappingListStateResource);
    });

    it('should have list item with mapping', () => {
      const comp = getElementFromFixtureByType(fixture, AggregationMappingListItemComponent);
      expect(comp.aggregationMapping).toEqual(
        getEmbeddedResources(aggregationMappingListStateResource, AggregationMappingListLinkRel.LIST)[0],
      );
    });
  });
});
