import { BinaryFile2ContainerComponent, BinaryFileModule } from '@alfa-client/binary-file';
import { BinaryFileResource } from '@alfa-client/binary-file-shared';
import {
  convertForDataTest,
  ConvertForDataTestPipe,
  ConvertProblemDetailToErrorMessagesPipe,
  createEmptyStateResource,
  createErrorStateResource,
  createStateResource,
} from '@alfa-client/tech-shared';
import {
  existsAsHtmlElement,
  getElementComponentFromFixtureByCss,
  notExistsAsHtmlElement,
  triggerEvent,
} from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { expect } from '@jest/globals';
import { AttachmentComponent } from '@ods/system';
import { MockComponent, MockModule } from 'ng-mocks';
import {
  createBinaryFileResource,
  createFile,
  createLoadingBinaryFileStateResource,
} from '../../../../../binary-file-shared/test/binary-file';
import { getDataTestIdOf } from '../../../../../tech-shared/test/data-test';
import { createProblemDetail } from '../../../../../tech-shared/test/error';
import { FileUploadListItemComponent } from './file-upload-list-item.component';

describe('FileUploadListItemComponent', () => {
  let component: FileUploadListItemComponent;
  let fixture: ComponentFixture<FileUploadListItemComponent>;

  const file: File = createFile();
  const binaryFileResource: BinaryFileResource = createBinaryFileResource();
  const attachmentTestId: string = getDataTestIdOf(convertForDataTest(file.name) + '-file-upload-list-item-attachment-upload');
  const binaryFileContainerTestId: string = getDataTestIdOf(
    convertForDataTest(binaryFileResource.name) + '-file-upload-list-item-uploaded',
  );

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [FileUploadListItemComponent, ConvertProblemDetailToErrorMessagesPipe, ConvertForDataTestPipe],
      declarations: [MockModule(BinaryFileModule), MockComponent(BinaryFile2ContainerComponent)],
    }).compileComponents();

    fixture = TestBed.createComponent(FileUploadListItemComponent);
    component = fixture.componentInstance;
    component.uploadFile = { uploadedFile: createEmptyStateResource() };
    fixture.detectChanges();
  });

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    describe('template', () => {
      beforeEach(() => {
        component.uploadFile.fileToUpload = file;
      });

      describe('attachment upload', () => {
        it('should exists on loading', () => {
          component.uploadFile.uploadedFile = createLoadingBinaryFileStateResource();

          fixture.detectChanges();

          existsAsHtmlElement(fixture, attachmentTestId);
        });

        it('should exists on error', () => {
          component.uploadFile.uploadedFile = createErrorStateResource(createProblemDetail());

          fixture.detectChanges();

          existsAsHtmlElement(fixture, attachmentTestId);
        });

        it('should NOT exists on loaded', () => {
          component.uploadFile.uploadedFile = createStateResource(binaryFileResource);

          fixture.detectChanges();

          notExistsAsHtmlElement(fixture, attachmentTestId);
        });

        it('should have inputs', () => {
          component.uploadFile.fileToUpload = file;
          component.uploadFile.uploadedFile = createEmptyStateResource(true);

          fixture.detectChanges();

          const attachmentComponent: AttachmentComponent = getElementComponentFromFixtureByCss(fixture, attachmentTestId);

          expect(attachmentComponent.loadingCaption).toEqual(component.uploadFile.fileToUpload.name);
          expect(attachmentComponent.errorMessages).toEqual([]);
          expect(attachmentComponent.isLoading).toEqual(true);
        });
      });

      describe('uploaded file', () => {
        it('should exists', () => {
          component.uploadFile.uploadedFile = createStateResource(binaryFileResource);

          fixture.detectChanges();

          existsAsHtmlElement(fixture, binaryFileContainerTestId);
        });

        it('should NOT exists', () => {
          component.uploadFile.uploadedFile = createEmptyStateResource(true);

          fixture.detectChanges();

          notExistsAsHtmlElement(fixture, binaryFileContainerTestId);
        });

        it('should have inputs', () => {
          component.uploadFile.uploadedFile = createStateResource(binaryFileResource);

          fixture.detectChanges();

          const binaryFileComponent: BinaryFile2ContainerComponent = getElementComponentFromFixtureByCss(
            fixture,
            binaryFileContainerTestId,
          );

          expect(binaryFileComponent.file).toEqual(component.uploadFile.uploadedFile.resource);
          expect(binaryFileComponent.deletable).toEqual(true);
        });

        describe('output', () => {
          describe('startDelete', () => {
            it('should emit', () => {
              component.delete.emit = jest.fn();
              component.key = 'test';
              component.uploadFile.uploadedFile = createStateResource(binaryFileResource);

              fixture.detectChanges();

              triggerEvent({
                fixture,
                elementSelector: binaryFileContainerTestId,
                name: 'startDelete',
                data: binaryFileResource,
              });

              expect(component.delete.emit).toHaveBeenCalledWith({ key: component.key, binaryFileResource });
            });
          });
        });
      });
    });
  });
});
