/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CollaborationListResource } from '@alfa-client/collaboration-shared';
import { VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Component, Input, OnInit } from '@angular/core';
import { CollaborationService } from 'libs/collaboration-shared/src/lib/collaboration.service';
import { Observable } from 'rxjs';
import { CollaborationRequestFormService } from '../../collaboration-request-form/collaboration.request.formservice';

@Component({
  selector: 'alfa-organisations-einheit-container',
  templateUrl: './organisations-einheit-container.component.html',
  providers: [CollaborationRequestFormService],
})
export class OrganisationsEinheitContainerComponent implements OnInit {
  @Input() public vorgang: VorgangWithEingangResource;
  @Input() public collaborationListResource: CollaborationListResource;

  public isFormVisible$: Observable<boolean>;

  public readonly vorgangLinkRel = VorgangWithEingangLinkRel;

  constructor(
    public service: CollaborationService,
    public formService: CollaborationRequestFormService,
  ) {}

  ngOnInit(): void {
    this.isFormVisible$ = this.service.isOrganisationsEinheitFormVisible();
  }

  public hideForm(): void {
    this.service.hideOrganisationseinheitForm();
    this.formService.reset();
  }

  public showForm(): void {
    this.service.showOrganisationsEinheitForm();
  }
}
