/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  CollaborationLevels,
  CollaborationListLinkRel,
  CollaborationListResource,
  CollaborationResource,
} from '@alfa-client/collaboration-shared';
import { createEmptyStateResource, createStateResource } from '@alfa-client/tech-shared';
import { SpinnerComponent } from '@alfa-client/ui';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createCollaboration, createCollaborationListResource } from 'libs/collaboration-shared/test/collaboration';
import {
  ExterneFachstelleListItemContainerComponent,
} from 'libs/externe-fachstelle/src/lib/externe-fachstelle-list-item-container/externe-fachstelle-list-item-container.component';
import {
  OrganisationsEinheitListItemContainerComponent,
} from 'libs/organisations-einheit/src/lib/organisations-einheit-list-item-container/organisations-einheit-list-item-container.component';
import { MockComponent } from 'ng-mocks';
import { CollaborationListContainerComponent } from './collaboration-list-container.component';
import { toResource } from 'libs/tech-shared/test/resource';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { existsAsHtmlElement } from '@alfa-client/test-utils';
import { CollaborationRequestComponent } from './collaboration-request/collaboration-request.component';

describe('CollaborationListContainerComponent', () => {
  let component: CollaborationListContainerComponent;
  let fixture: ComponentFixture<CollaborationListContainerComponent>;

  const organisationsEinheitListItem: string = getDataTestIdOf('organisations-einheit-list-item');
  const externeFachstelleListItem: string = getDataTestIdOf('externe-fachstelle-list-item');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [
        CollaborationListContainerComponent,
        MockComponent(OrganisationsEinheitListItemContainerComponent),
        MockComponent(ExterneFachstelleListItemContainerComponent),
        MockComponent(CollaborationRequestComponent),
        MockComponent(SpinnerComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(CollaborationListContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    const collaboration: CollaborationResource = toResource(createCollaboration());

    beforeEach(() => {
      component.collaborations = [collaboration];
    })

    describe('alfa-organisations-einheit-list-item-container', () => {
      it('should be rendered if collaborationLevel is ORGANISATIONS_EINHEIT', () => {
        collaboration.collaborationLevel = CollaborationLevels.ORGANISATIONS_EINHEIT;
        fixture.detectChanges();

        existsAsHtmlElement(fixture, organisationsEinheitListItem);
      });
    })

    describe('alfa-externe-fachstelle-list-item-container', () => {
      it('should be rendered if collaborationLevel is EXTERNE_FACHSTELLE', () => {
        collaboration.collaborationLevel = CollaborationLevels.EXTERNE_FACHSTELLE;
        fixture.detectChanges();

        existsAsHtmlElement(fixture, externeFachstelleListItem);
      });
    })
  })

  describe('component', () => {
    describe('getCollaborations', () => {
      it('should return empty array if state resource is null', () => {
        component.collaborationStateListResource = null;

        expect(component.getCollaborations()).toEqual([]);
      });

      it('should return empty array if resource is null', () => {
        component.collaborationStateListResource = createEmptyStateResource();

        expect(component.getCollaborations()).toEqual([]);
      });

      it('should return embedded resource', () => {
        const collaborationListResource: CollaborationListResource = createCollaborationListResource();
        component.collaborationStateListResource = createStateResource(collaborationListResource);

        expect(component.getCollaborations()).toEqual(
          collaborationListResource._embedded[CollaborationListLinkRel.COLLABORATION_LIST],
        );
      });
    });
  });
});
