/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createStateResource, StateResource } from '@alfa-client/tech-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createCommandErrorStateResource } from 'libs/command-shared/test/command';
import { createApiError } from 'libs/tech-shared/test/error';
import { createDummyResource } from '../../../../tech-shared/test/resource';
import { ButtonWithSpinnerComponent } from './button-with-spinner.component';

describe('ButtonWithSpinnerComponent', () => {
  let component: ButtonWithSpinnerComponent;
  let fixture: ComponentFixture<ButtonWithSpinnerComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [ButtonWithSpinnerComponent],
    }).compileComponents();

    fixture = TestBed.createComponent(ButtonWithSpinnerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('set stateResource', () => {
    it('should set stateResource', () => {
      const stateResource: StateResource<unknown> = createStateResource(createDummyResource());

      component.stateResource = stateResource;

      expect(component._stateResource).toBe(stateResource);
    });

    it('should not set stateResource', () => {
      component.stateResource = null;

      expect(component._stateResource).not.toBe(null);
    });
  });

  describe('isLoading', () => {
    it('should return false', () => {
      component._stateResource.loading = component._stateResource.reload = false;

      const isLoading: boolean = component.isLoading;

      expect(isLoading).toBeFalsy();
    });

    it('should return true if stateResource is loading', () => {
      component._stateResource.loading = true;
      component._stateResource.reload = false;

      const isLoading: boolean = component.isLoading;

      expect(isLoading).toBeTruthy();
    });

    it('should return true if stateResource is reloading', () => {
      component._stateResource.loading = false;
      component._stateResource.reload = true;

      const isLoading: boolean = component.isLoading;

      expect(isLoading).toBeTruthy();
    });
  });

  describe('isError', () => {
    it('should return false if error is not set', () => {
      component._stateResource.error = null;

      const isError: boolean = component.isError;

      expect(isError).toBeFalsy();
    });

    it('should return false if error is set and error is ApiError', () => {
      component._stateResource.error = createApiError();

      const isError: boolean = component.isError;

      expect(isError).toBeFalsy();
    });

    it('should return true if error is set and error is not ApiError', () => {
      component._stateResource = createCommandErrorStateResource();

      const isError: boolean = component.isError;

      expect(isError).toBeTruthy();
    });
  });
});
