/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { APP_BASE_HREF } from '@angular/common';
import { importProvidersFrom } from '@angular/core';
import { RouterModule } from '@angular/router';
import { applicationConfig, moduleMetadata, type Meta, type StoryObj } from '@storybook/angular';
import { OfficeIconComponent } from '../../icons/office-icon/office-icon.component';
import { NavItemComponent } from '../nav-item/nav-item.component';
import { NavbarComponent } from './navbar.component';

const meta: Meta<NavbarComponent> = {
  title: 'Navbar',
  component: NavbarComponent,
  excludeStories: /.*Data$/,
  tags: ['autodocs'],
  decorators: [
    applicationConfig({
      providers: [importProvidersFrom(RouterModule.forRoot([]))],
    }),
    moduleMetadata({
      imports: [NavItemComponent, OfficeIconComponent],
      providers: [
        {
          provide: APP_BASE_HREF,
          useValue: '/',
        },
      ],
    }),
  ],
};

export default meta;
type Story = StoryObj<NavbarComponent>;

export const Default: Story = {
  args: {},
  render: () => ({
    template: `<ods-navbar>
      <ods-nav-item caption="First link" path="/"><ods-office-icon icon /></ods-nav-item>
      <ods-nav-item caption="Second link" path="/second"><ods-office-icon icon /></ods-nav-item>
      <hr />
      <ods-nav-item caption="Third link" path="/third"><ods-office-icon icon /></ods-nav-item>
    </ods-navbar>`,
  }),
};
