/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { mock } from '@alfa-client/test-utils';
import { OzgcloudStrokedButtonWithSpinnerComponent, OzgcloudTextEditorComponent } from '@alfa-client/ui';
import { VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ReactiveFormsModule, UntypedFormControl, UntypedFormGroup } from '@angular/forms';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIcon } from '@angular/material/icon';
import { MatInputModule } from '@angular/material/input';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { ForwardingByEmailFormComponent } from './forwarding-by-email-form.component';
import { ForwardingByEmailFormService } from './forwarding-by-email-form.service';

describe('ForwardingByEmailFormComponent', () => {
  let component: ForwardingByEmailFormComponent;
  let fixture: ComponentFixture<ForwardingByEmailFormComponent>;

  const form: UntypedFormGroup = new UntypedFormGroup({
    [ForwardingByEmailFormService.FIELD_PASSWORD]: new UntypedFormControl(null),
    [ForwardingByEmailFormService.FIELD_EMAIL]: new UntypedFormControl(null),
  });

  const formService = { ...mock(ForwardingByEmailFormService), form };

  const vorgangWithEingang: VorgangWithEingangResource = createVorgangWithEingangResource();

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        ForwardingByEmailFormComponent,
        MatIcon,
        MockComponent(OzgcloudStrokedButtonWithSpinnerComponent),
        MockComponent(OzgcloudTextEditorComponent),
      ],
      imports: [MatFormFieldModule, MatInputModule, ReactiveFormsModule, BrowserAnimationsModule],
      providers: [
        {
          provide: ForwardingByEmailFormService,
          useValue: formService,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(ForwardingByEmailFormComponent);
    component = fixture.componentInstance;
    component.vorgang = vorgangWithEingang;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('zustaendige stelle email exists', () => {
    it('should return false if vorgang is undefined', () => {
      component.vorgang = undefined;

      var result: boolean = component.zustaendigeStelleEmailExists();

      expect(result).toBeFalsy();
    });

    it('should return true if exists', () => {
      component.vorgang = vorgangWithEingang;

      var result: boolean = component.zustaendigeStelleEmailExists();

      expect(result).toBeTruthy();
    });

    it('should return false if NOT exists', () => {
      component.vorgang = {
        ...vorgangWithEingang,
        eingang: { ...vorgangWithEingang.eingang, zustaendigeStelle: { email: null } },
      };

      var result: boolean = component.zustaendigeStelleEmailExists();

      expect(result).toBeFalsy();
    });
  });

  describe('patch email field', () => {
    it('should set email', () => {
      component.vorgang = vorgangWithEingang;

      component.patchEmail();

      expect(formService.patchField).toHaveBeenCalledWith('email', vorgangWithEingang.eingang.zustaendigeStelle.email);
    });
  });
});
