import { CommandLinkRel, CommandResource } from '@alfa-client/command-shared';
import { ForwardingService } from '@alfa-client/forwarding-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { mock, Mock, triggerEvent } from '@alfa-client/test-utils';
import { OzgcloudDialogService } from '@alfa-client/ui';
import { OrganisationsEinheitService, ZUSTAENDIGE_STELLE_SERVICE } from '@alfa-client/zustaendige-stelle-shared';
import { AsyncPipe } from '@angular/common';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { faker } from '@faker-js/faker/.';
import { ResourceUri } from '@ngxp/rest';
import { createCommandStateResource } from 'libs/command-shared/test/command';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { singleColdCompleted } from 'libs/tech-shared/test/marbles';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { ForwardingDialogContainerComponent } from './forwarding-dialog-container.component';
import { ForwardingDialogComponent } from './forwarding-dialog/forwarding-dialog.component';

describe('ForwardingDialogContainerComponent', () => {
  let component: ForwardingDialogContainerComponent;
  let fixture: ComponentFixture<ForwardingDialogContainerComponent>;

  const forwardingDialog: string = getDataTestIdOf('forwarding-dialog');

  let service: Mock<ForwardingService>;
  let organisationsEinheitService: Mock<OrganisationsEinheitService>;
  let dialogService: Mock<OzgcloudDialogService>;

  beforeEach(async () => {
    service = mock(ForwardingService);
    organisationsEinheitService = mock(OrganisationsEinheitService);
    dialogService = mock(OzgcloudDialogService);

    await TestBed.configureTestingModule({
      imports: [ForwardingDialogContainerComponent, AsyncPipe],
      declarations: [MockComponent(ForwardingDialogComponent)],
      providers: [
        {
          provide: ForwardingService,
          useValue: service,
        },
        {
          provide: OzgcloudDialogService,
          useValue: dialogService,
        },
      ],
    })
      .overrideComponent(ForwardingDialogContainerComponent, {
        set: {
          providers: [
            {
              provide: ZUSTAENDIGE_STELLE_SERVICE,
              useValue: organisationsEinheitService,
            },
          ],
        },
      })
      .compileComponents();

    fixture = TestBed.createComponent(ForwardingDialogContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('forward button', () => {
    const targetUri: ResourceUri = faker.internet.url();

    it('should call forward on click', () => {
      component.forward = jest.fn();

      triggerEvent({ fixture, elementSelector: forwardingDialog, name: 'forward', data: targetUri });

      expect(component.forward).toHaveBeenCalledWith(targetUri);
    });
  });

  describe('forward', () => {
    const targetUri: ResourceUri = faker.internet.url();

    const commandStateResource: StateResource<CommandResource> = createCommandStateResource([CommandLinkRel.EFFECTED_RESOURCE]);

    beforeEach(() => {
      service.forward.mockReturnValue(of(commandStateResource));
    });

    it('should call service with uri', () => {
      component.forward(targetUri);

      expect(service.forward).toHaveBeenCalledWith(targetUri);
    });

    it('should set service response', () => {
      component.forward(targetUri);

      expect(component.forwardCommandStateResource$).toBeObservable(singleColdCompleted(commandStateResource));
    });

    it('should call dialog service to close all if command is done', () => {
      component.forward(targetUri);
      component.forwardCommandStateResource$.subscribe();

      expect(dialogService.closeAll).toHaveBeenCalled();
    });
  });
});
