/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { CommandOrder, CommandResource } from '@alfa-client/command-shared';
import { VorgangStatusLabel } from '@alfa-client/vorgang-shared';
import { createCommandResource } from 'libs/command-shared/test/command';
import { MockComponent } from 'ng-mocks';
import { HistorieItemHeaderComponent } from '../historie-item-header/historie-item-header.component';
import { HistorieItemVorgangStatusComponent } from './historie-item-vorgang-status.component';

describe('HistorieItemVorgangStatusComponent', () => {
  let component: HistorieItemVorgangStatusComponent;
  let fixture: ComponentFixture<HistorieItemVorgangStatusComponent>;

  const vorgangStatusCommand: CommandResource = {
    ...createCommandResource(),
    order: CommandOrder.VORGANG_ANNEHMEN,
  };

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        HistorieItemVorgangStatusComponent,
        MockComponent(HistorieItemHeaderComponent),
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(HistorieItemVorgangStatusComponent);
    component = fixture.componentInstance;
    component.command = vorgangStatusCommand;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    const allVorgangStatusCommandOrder: CommandOrder[] = [
      CommandOrder.VORGANG_ANNEHMEN,
      CommandOrder.VORGANG_VERWERFEN,
      CommandOrder.VORGANG_ZURUECKHOLEN,
      CommandOrder.VORGANG_BEARBEITEN,
      CommandOrder.VORGANG_BESCHEIDEN,
      CommandOrder.VORGANG_ZURUECKSTELLEN,
      CommandOrder.VORGANG_ABSCHLIESSEN,
      CommandOrder.VORGANG_WIEDEREROEFFNEN,
    ];

    const vorgangStatusLabelByCommandOrder = {
      [CommandOrder.VORGANG_ANNEHMEN]: VorgangStatusLabel.ANGENOMMEN,
      [CommandOrder.VORGANG_VERWERFEN]: VorgangStatusLabel.VERWORFEN,
      [CommandOrder.VORGANG_ZURUECKHOLEN]: VorgangStatusLabel.NEU,
      [CommandOrder.VORGANG_BEARBEITEN]: VorgangStatusLabel.IN_BEARBEITUNG,
      [CommandOrder.VORGANG_BESCHEIDEN]: VorgangStatusLabel.BESCHIEDEN,
      [CommandOrder.VORGANG_ZURUECKSTELLEN]: VorgangStatusLabel.ANGENOMMEN,
      [CommandOrder.VORGANG_ABSCHLIESSEN]: VorgangStatusLabel.ABGESCHLOSSEN,
      [CommandOrder.VORGANG_WIEDEREROEFFNEN]: VorgangStatusLabel.IN_BEARBEITUNG,
    };

    it.each(allVorgangStatusCommandOrder)(
      'should set headline for order %s',
      (order: CommandOrder) => {
        component.command = { ...vorgangStatusCommand, order };

        component.ngOnInit();

        expect(component.headline).toBe(
          `den Vorgang in den Status ${vorgangStatusLabelByCommandOrder[order]} versetzt.`,
        );
      },
    );
  });
});
