/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { KommentarLinkRel, KommentarListResource, KommentarResource, KommentarService } from '@alfa-client/kommentar-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { Component, inject, Input } from '@angular/core';
import { getUrl, hasLink, ResourceUri } from '@ngxp/rest';

@Component({
  selector: 'alfa-kommentar-list-item-in-vorgang',
  templateUrl: './kommentar-list-item-in-vorgang.component.html',
  styleUrls: ['./kommentar-list-item-in-vorgang.component.scss'],
})
export class KommentarListItemInVorgangComponent {
  @Input() kommentar: KommentarResource;
  @Input() kommentarListStateResource: StateResource<KommentarListResource>;

  @Input() set currentlyEdited(value: ResourceUri) {
    this.editMode &&= value === getUrl(this.kommentar);
  }

  public kommentarService = inject(KommentarService);

  public editMode: boolean = false;

  public readonly kommentarLinkRel = KommentarLinkRel;

  public edit(): void {
    this.editMode = hasLink(this.kommentar, KommentarLinkRel.EDIT);
    this.kommentarService.setCurrentlyEdited(getUrl(this.kommentar));
  }
}
