/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { mock } from '@alfa-client/test-utils';
import { OzgcloudStrokedButtonWithSpinnerComponent } from '@alfa-client/ui';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MAT_DIALOG_DATA, MatDialogModule, MatDialogRef } from '@angular/material/dialog';
import { MatIcon } from '@angular/material/icon';
import { faker } from '@faker-js/faker';
import { OAuthService } from 'angular-oauth2-oidc';
import { createIssue } from 'libs/tech-shared/test/error';
import { MockComponent } from 'ng-mocks';
import { InternalServerErrorDialogComponent } from './internal-server-error-dialog.component';

describe('InternalServerErrorDialogComponent', () => {
  let component: InternalServerErrorDialogComponent;
  let fixture: ComponentFixture<InternalServerErrorDialogComponent>;

  let dialogData: any;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [
        MatDialogModule,
        InternalServerErrorDialogComponent,
        MatIcon,
        MockComponent(OzgcloudStrokedButtonWithSpinnerComponent),
      ],
      providers: [
        {
          provide: MatDialogRef,
          useValue: {},
        },
        {
          provide: OAuthService,
          useValue: mock(OAuthService),
        },
        {
          provide: MAT_DIALOG_DATA,
          useValue: dialogData,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(InternalServerErrorDialogComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('exception id', () => {
    it('should be hidden', () => {
      expect(fixture.nativeElement).not.toHaveTextContent('ID:');
    });

    it('should be visible', () => {
      const exceptionId = faker.string.uuid();
      dialogData = { error: { ...{ issues: [createIssue()] }, id: exceptionId } };
      fixture.detectChanges();

      expect(fixture.nativeElement).not.toHaveTextContent(`ID: ${dialogData.error.issues[0].exceptionId}`);
    });
  });
});
