/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Mock, mock } from '@alfa-client/test-utils';
import { Dialog, DialogConfig, DialogRef } from '@angular/cdk/dialog';
import { TestBed } from '@angular/core/testing';
import { OzgcloudDialogService } from './ozgcloud-dialog.service';

describe('OzgcloudDialogService', () => {
  let service: OzgcloudDialogService;
  let dialog: Mock<Dialog>;

  const component = <any>{ name: 'Component' };
  const dialogData = { id: 'ZumBeispiel' };
  const dialogConfig: DialogConfig = {
    hasBackdrop: true,
    disableClose: true,
  };
  const dialogConfigWithData: DialogConfig = { data: dialogData };
  const viewContainerRef = <any>{};
  const dialogConfigWithDataAndViewContainerRef: DialogConfig = {
    data: dialogData,
    viewContainerRef,
  };
  const dialogConfigWithOwnConfigAndViewContainerRef: DialogConfig = {
    ...dialogConfig,
    viewContainerRef,
  };
  const dialogConfigWithOutDataAndWithViewContainerRef: DialogConfig = {
    viewContainerRef,
  };

  beforeEach(() => {
    dialog = mock(Dialog);

    TestBed.configureTestingModule({
      providers: [
        {
          provide: Dialog,
          useValue: dialog,
        },
      ],
    });
    service = TestBed.inject(OzgcloudDialogService);
  });

  it('should be created', () => {
    expect(service).toBeTruthy();
  });

  describe('open', () => {
    it('should open dialog with data', () => {
      service.open(component, dialogData);

      expect(dialog.open).toHaveBeenCalledWith(component, dialogConfigWithData);
    });

    it('should open dialog wihtout data', () => {
      service.open(component);

      expect(dialog.open).toHaveBeenCalledWith(component, undefined);
    });
  });

  describe('open in context', () => {
    const dialogRefMock: Mock<DialogRef> = mock(DialogRef);

    beforeEach(() => {
      service.openInCallingComponentContext = jest.fn().mockReturnValue(dialogRefMock);
    });

    it('should call open in calling component context', () => {
      service.openInContext(component, viewContainerRef, dialogData);

      expect(service.openInCallingComponentContext).toHaveBeenCalledWith(component, viewContainerRef, dialogData);
    });

    it('should return dialog ref', () => {
      const dialogRef: DialogRef = service.openInContext(component, viewContainerRef, dialogData);

      expect(dialogRef).toBe(dialogRefMock);
    });
  });

  describe('openInCallingComponentContext', () => {
    it('should open dialog with data', () => {
      service.openInCallingComponentContext(component, viewContainerRef, dialogData);

      expect(dialog.open).toHaveBeenCalledWith(component, dialogConfigWithDataAndViewContainerRef);
    });

    it('should open dialog with custom config', () => {
      service.openInCallingComponentContext(component, viewContainerRef, null, dialogConfig);

      expect(dialog.open).toHaveBeenCalledWith(component, dialogConfigWithOwnConfigAndViewContainerRef);
    });

    it('should open dialog without data and custom config', () => {
      service.openInCallingComponentContext(component, viewContainerRef);

      expect(dialog.open).toHaveBeenCalledWith(component, dialogConfigWithOutDataAndWithViewContainerRef);
    });
  });

  describe('openWizard', () => {
    beforeEach(() => {
      service.openInCallingComponentContext = jest.fn();
    });

    it('should open wizard dialog', () => {
      service.openWizard(component, viewContainerRef);

      expect(service.openInCallingComponentContext).toHaveBeenCalledWith(
        component,
        viewContainerRef,
        undefined,
        service.WIZARD_DIALOG_CONFIG,
      );
    });

    it('should open wizard dialog with data', () => {
      service.openWizard(component, viewContainerRef, dialogData);

      expect(service.openInCallingComponentContext).toHaveBeenCalledWith(
        component,
        viewContainerRef,
        dialogData,
        service.WIZARD_DIALOG_CONFIG,
      );
    });
  });

  describe('open full screen dialog', () => {
    it('should call openInCallingComponentContext', () => {
      service.openInCallingComponentContext = jest.fn();

      service.openFullScreenDialog(component, viewContainerRef, dialogData);

      expect(service.openInCallingComponentContext).toHaveBeenCalledWith(
        component,
        viewContainerRef,
        dialogData,
        service.GREY_BLUR_CONFIG,
      );
    });
  });
});
