/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommandResource } from '@alfa-client/command-shared';
import { StateResource, createEmptyStateResource, isLoaded } from '@alfa-client/tech-shared';
import { VorgangService, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { Observable, of, tap } from 'rxjs';

@Component({
  selector: 'alfa-vorgang-process-vorgang-container',
  templateUrl: './vorgang-process-vorgang-container.component.html',
  styleUrls: ['./vorgang-process-vorgang-container.component.scss'],
})
export class ProcessVorgangContainerComponent {
  @Input() vorgangWithEingang: VorgangWithEingangResource;

  @Output() public closeMenu: EventEmitter<void> = new EventEmitter();

  public commandStateResource$: Observable<StateResource<CommandResource>> = of(
    createEmptyStateResource<CommandResource>(),
  );

  constructor(private vorgangService: VorgangService) {}

  public processVorgang(): void {
    this.commandStateResource$ = this.vorgangService
      .processVorgang(this.vorgangWithEingang)
      .pipe(tap((vorgangExportStateResource) => this.handleCommand(vorgangExportStateResource)));
  }

  handleCommand(vorgangExportStateResource: StateResource<CommandResource>): void {
    if (isLoaded(vorgangExportStateResource)) this.closeMenu.emit();
  }
}
