/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { HintContainerComponent } from '@alfa-client/hint';
import { HasLinkPipe, createStateResource } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { createApiRootResource } from 'libs/api-root-shared/test/api-root';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { VorgangListSearchComponent } from './vorgang-list-search.component';

describe('VorgangListSearchComponent', () => {
  let component: VorgangListSearchComponent;
  let fixture: ComponentFixture<VorgangListSearchComponent>;

  const hintContainer: string = getDataTestIdOf('hint-container');
  const emptySearchResult: string = getDataTestIdOf('vorgang-list-empty-search-result');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        VorgangListSearchComponent,
        HasLinkPipe,
        MockComponent(HintContainerComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(VorgangListSearchComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('if hints link is not present', () => {
    it('should show search result', () => {
      component.apiRootStateResource = createStateResource(createApiRootResource());

      fixture.detectChanges();

      existsAsHtmlElement(fixture, emptySearchResult);
    });

    it('should hide hint container', () => {
      component.apiRootStateResource = createStateResource(createApiRootResource());

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, hintContainer);
    });
  });
});
